@@ -3,13 +3,15 @@
 #
 #  (C) Paul Evans, 2022 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Elem 0.06;
+package Syntax::Operator::Elem 0.07;
 
 use v5.14;
 use warnings;
 
 use Carp;
 
+use meta;
+
 =encoding UTF-8
 
 =head1 NAME
@@ -92,12 +94,15 @@ sub apply
           : delete $^H{"Syntax::Operator::Elem/elem"};
    }
 
+   my $callerpkg;
+
    foreach (qw( elem_str elem_num )) {
       next unless delete $syms{$_};
 
-      no strict 'refs';
-      $on ? *{"${caller}::$_"} = \&{$_}
-          : warn "TODO: implement unimport of package symbol";
+      $callerpkg //= meta::get_package( $caller );
+
+      $on ? $callerpkg->add_symbol( '&'.$_ => \&{$_} )
+          : $callerpkg->remove_symbol( '&'.$_ );
    }
 
    croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
